# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'CGNS/NAV/T/Q7FormWindow.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Q7FormWindow(object):
    def setupUi(self, Q7FormWindow):
        Q7FormWindow.setObjectName("Q7FormWindow")
        Q7FormWindow.resize(550, 600)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Q7FormWindow.sizePolicy().hasHeightForWidth())
        Q7FormWindow.setSizePolicy(sizePolicy)
        Q7FormWindow.setMinimumSize(QtCore.QSize(550, 600))
        Q7FormWindow.setMaximumSize(QtCore.QSize(999999, 999999))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/cgSpy.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Q7FormWindow.setWindowIcon(icon)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(Q7FormWindow)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.bLockPanel = QtWidgets.QPushButton(Q7FormWindow)
        self.bLockPanel.setEnabled(False)
        self.bLockPanel.setMinimumSize(QtCore.QSize(25, 25))
        self.bLockPanel.setMaximumSize(QtCore.QSize(25, 25))
        self.bLockPanel.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/panel-lock.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bLockPanel.setIcon(icon1)
        self.bLockPanel.setObjectName("bLockPanel")
        self.horizontalLayout_2.addWidget(self.bLockPanel)
        self.ePath = QtWidgets.QLineEdit(Q7FormWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ePath.sizePolicy().hasHeightForWidth())
        self.ePath.setSizePolicy(sizePolicy)
        self.ePath.setMinimumSize(QtCore.QSize(510, 0))
        self.ePath.setObjectName("ePath")
        self.horizontalLayout_2.addWidget(self.ePath)
        self.verticalLayout_3.addLayout(self.horizontalLayout_2)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_2 = QtWidgets.QLabel(Q7FormWindow)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.eName = QtWidgets.QLineEdit(Q7FormWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.eName.sizePolicy().hasHeightForWidth())
        self.eName.setSizePolicy(sizePolicy)
        self.eName.setMinimumSize(QtCore.QSize(220, 0))
        self.eName.setObjectName("eName")
        self.horizontalLayout.addWidget(self.eName)
        self.label_3 = QtWidgets.QLabel(Q7FormWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout.addWidget(self.label_3)
        self.eType = QtWidgets.QComboBox(Q7FormWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.eType.sizePolicy().hasHeightForWidth())
        self.eType.setSizePolicy(sizePolicy)
        self.eType.setMinimumSize(QtCore.QSize(200, 0))
        self.eType.setObjectName("eType")
        self.horizontalLayout.addWidget(self.eType)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.verticalLayout_3.addLayout(self.horizontalLayout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.tabWidget = QtWidgets.QTabWidget(Q7FormWindow)
        self.tabWidget.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setObjectName("tabWidget")
        self.tData = QtWidgets.QWidget()
        self.tData.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tData.sizePolicy().hasHeightForWidth())
        self.tData.setSizePolicy(sizePolicy)
        self.tData.setObjectName("tData")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.tData)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.verticalLayout.setObjectName("verticalLayout")
        self.frame_3 = QtWidgets.QFrame(self.tData)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_3.sizePolicy().hasHeightForWidth())
        self.frame_3.setSizePolicy(sizePolicy)
        self.frame_3.setMinimumSize(QtCore.QSize(600, 60))
        self.frame_3.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_3.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_3.setObjectName("frame_3")
        self.label_6 = QtWidgets.QLabel(self.frame_3)
        self.label_6.setGeometry(QtCore.QRect(6, 40, 602, 16))
        self.label_6.setObjectName("label_6")
        self.eItems = QtWidgets.QLineEdit(self.frame_3)
        self.eItems.setGeometry(QtCore.QRect(46, 35, 160, 22))
        self.eItems.setObjectName("eItems")
        self.label = QtWidgets.QLabel(self.frame_3)
        self.label.setGeometry(QtCore.QRect(5, 10, 32, 16))
        self.label.setObjectName("label")
        self.cDataType = QtWidgets.QComboBox(self.frame_3)
        self.cDataType.setGeometry(QtCore.QRect(45, 5, 51, 23))
        self.cDataType.setObjectName("cDataType")
        self.eDims = QtWidgets.QLineEdit(self.frame_3)
        self.eDims.setGeometry(QtCore.QRect(96, 5, 111, 24))
        self.eDims.setObjectName("eDims")
        self.line = QtWidgets.QFrame(self.frame_3)
        self.line.setGeometry(QtCore.QRect(213, 4, 16, 46))
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.label_5 = QtWidgets.QLabel(self.frame_3)
        self.label_5.setGeometry(QtCore.QRect(230, 10, 58, 16))
        self.label_5.setObjectName("label_5")
        self.label_24 = QtWidgets.QLabel(self.frame_3)
        self.label_24.setGeometry(QtCore.QRect(230, 35, 47, 16))
        self.label_24.setObjectName("label_24")
        self.sMinH = QtWidgets.QSpinBox(self.frame_3)
        self.sMinH.setGeometry(QtCore.QRect(270, 6, 92, 22))
        self.sMinH.setObjectName("sMinH")
        self.label_7 = QtWidgets.QLabel(self.frame_3)
        self.label_7.setGeometry(QtCore.QRect(370, 10, 58, 16))
        self.label_7.setObjectName("label_7")
        self.sMinV = QtWidgets.QSpinBox(self.frame_3)
        self.sMinV.setGeometry(QtCore.QRect(415, 5, 81, 22))
        self.sMinV.setObjectName("sMinV")
        self.cRowColSize = QtWidgets.QComboBox(self.frame_3)
        self.cRowColSize.setGeometry(QtCore.QRect(270, 35, 196, 22))
        self.cRowColSize.setObjectName("cRowColSize")
        self.bMinimize = QtWidgets.QPushButton(self.frame_3)
        self.bMinimize.setGeometry(QtCore.QRect(470, 34, 25, 25))
        self.bMinimize.setMinimumSize(QtCore.QSize(25, 25))
        self.bMinimize.setMaximumSize(QtCore.QSize(25, 25))
        self.bMinimize.setObjectName("bMinimize")
        self.verticalLayout.addWidget(self.frame_3)
        self.frame_5 = QtWidgets.QFrame(self.tData)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_5.sizePolicy().hasHeightForWidth())
        self.frame_5.setSizePolicy(sizePolicy)
        self.frame_5.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_5.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_5.setObjectName("frame_5")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.frame_5)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.tableView = Q7TableView(self.frame_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableView.sizePolicy().hasHeightForWidth())
        self.tableView.setSizePolicy(sizePolicy)
        self.tableView.setMinimumSize(QtCore.QSize(100, 100))
        self.tableView.viewport().setProperty("cursor", QtGui.QCursor(QtCore.Qt.CrossCursor))
        self.tableView.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.tableView.setAutoFillBackground(False)
        self.tableView.setSelectionMode(QtWidgets.QAbstractItemView.ContiguousSelection)
        self.tableView.setObjectName("tableView")
        self.tableView.horizontalHeader().setCascadingSectionResizes(False)
        self.tableView.verticalHeader().setCascadingSectionResizes(False)
        self.verticalLayout_12.addWidget(self.tableView)
        self.verticalLayout.addWidget(self.frame_5)
        self.verticalLayout_8.addLayout(self.verticalLayout)
        self.tabWidget.addTab(self.tData, "")
        self.tFiles = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tFiles.sizePolicy().hasHeightForWidth())
        self.tFiles.setSizePolicy(sizePolicy)
        self.tFiles.setObjectName("tFiles")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.tFiles)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.groupBox_3 = QtWidgets.QGroupBox(self.tFiles)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setObjectName("groupBox_3")
        self.label_9 = QtWidgets.QLabel(self.groupBox_3)
        self.label_9.setGeometry(QtCore.QRect(5, 25, 59, 27))
        self.label_9.setObjectName("label_9")
        self.eDestPath = QtWidgets.QLineEdit(self.groupBox_3)
        self.eDestPath.setGeometry(QtCore.QRect(40, 24, 453, 27))
        self.eDestPath.setObjectName("eDestPath")
        self.label_10 = QtWidgets.QLabel(self.groupBox_3)
        self.label_10.setGeometry(QtCore.QRect(6, 60, 45, 17))
        self.label_10.setObjectName("label_10")
        self.eDestFile = QtWidgets.QLineEdit(self.groupBox_3)
        self.eDestFile.setGeometry(QtCore.QRect(40, 54, 299, 27))
        self.eDestFile.setObjectName("eDestFile")
        self.label_23 = QtWidgets.QLabel(self.groupBox_3)
        self.label_23.setGeometry(QtCore.QRect(6, 121, 31, 17))
        self.label_23.setObjectName("label_23")
        self.lineEdit_18 = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEdit_18.setGeometry(QtCore.QRect(40, 115, 178, 27))
        self.lineEdit_18.setObjectName("lineEdit_18")
        self.label_8 = QtWidgets.QLabel(self.groupBox_3)
        self.label_8.setGeometry(QtCore.QRect(385, 60, 58, 16))
        self.label_8.setObjectName("label_8")
        self.lineEdit_2 = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEdit_2.setGeometry(QtCore.QRect(453, 55, 39, 22))
        self.lineEdit_2.setObjectName("lineEdit_2")
        self.eDestDir = QtWidgets.QLineEdit(self.groupBox_3)
        self.eDestDir.setGeometry(QtCore.QRect(40, 84, 298, 27))
        self.eDestDir.setObjectName("eDestDir")
        self.label_13 = QtWidgets.QLabel(self.groupBox_3)
        self.label_13.setGeometry(QtCore.QRect(5, 89, 45, 17))
        self.label_13.setObjectName("label_13")
        self.groupBox = QtWidgets.QGroupBox(self.groupBox_3)
        self.groupBox.setGeometry(QtCore.QRect(8, 160, 492, 96))
        self.groupBox.setObjectName("groupBox")
        self.checkBox_11 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_11.setGeometry(QtCore.QRect(10, 21, 151, 22))
        self.checkBox_11.setObjectName("checkBox_11")
        self.checkBox_8 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_8.setGeometry(QtCore.QRect(10, 43, 188, 22))
        self.checkBox_8.setObjectName("checkBox_8")
        self.checkBox_10 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_10.setGeometry(QtCore.QRect(10, 66, 188, 22))
        self.checkBox_10.setObjectName("checkBox_10")
        self.checkBox_18 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_18.setGeometry(QtCore.QRect(205, 20, 203, 22))
        self.checkBox_18.setObjectName("checkBox_18")
        self.cChildOfLink = QtWidgets.QCheckBox(self.groupBox)
        self.cChildOfLink.setGeometry(QtCore.QRect(205, 45, 232, 21))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.cChildOfLink.setFont(font)
        self.cChildOfLink.setObjectName("cChildOfLink")
        self.verticalLayout_6.addWidget(self.groupBox_3)
        self.verticalLayout_9.addLayout(self.verticalLayout_6)
        self.tabWidget.addTab(self.tFiles, "")
        self.tText = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tText.sizePolicy().hasHeightForWidth())
        self.tText.setSizePolicy(sizePolicy)
        self.tText.setObjectName("tText")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.tText)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.cFortranOrderOff = QtWidgets.QCheckBox(self.tText)
        self.cFortranOrderOff.setObjectName("cFortranOrderOff")
        self.horizontalLayout_4.addWidget(self.cFortranOrderOff)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.bRevert = QtWidgets.QPushButton(self.tText)
        self.bRevert.setMinimumSize(QtCore.QSize(25, 25))
        self.bRevert.setMaximumSize(QtCore.QSize(25, 25))
        self.bRevert.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/images/icons/subtree-sids-failed.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bRevert.setIcon(icon2)
        self.bRevert.setObjectName("bRevert")
        self.horizontalLayout_4.addWidget(self.bRevert)
        self.bCommit = QtWidgets.QPushButton(self.tText)
        self.bCommit.setMinimumSize(QtCore.QSize(25, 25))
        self.bCommit.setMaximumSize(QtCore.QSize(25, 25))
        self.bCommit.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/images/icons/save-log.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bCommit.setIcon(icon3)
        self.bCommit.setObjectName("bCommit")
        self.horizontalLayout_4.addWidget(self.bCommit)
        self.verticalLayout_10.addLayout(self.horizontalLayout_4)
        self.eText = Q7PythonEditor(self.tText)
        self.eText.setObjectName("eText")
        self.verticalLayout_10.addWidget(self.eText)
        self.tabWidget.addTab(self.tText, "")
        self.tPython = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tPython.sizePolicy().hasHeightForWidth())
        self.tPython.setSizePolicy(sizePolicy)
        self.tPython.setObjectName("tPython")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.tPython)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.frame_6 = QtWidgets.QFrame(self.tPython)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_6.sizePolicy().hasHeightForWidth())
        self.frame_6.setSizePolicy(sizePolicy)
        self.frame_6.setMinimumSize(QtCore.QSize(550, 125))
        self.frame_6.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_6.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_6.setObjectName("frame_6")
        self.label_11 = QtWidgets.QLabel(self.frame_6)
        self.label_11.setGeometry(QtCore.QRect(5, 5, 33, 27))
        self.label_11.setObjectName("label_11")
        self.comboBox_5 = QtWidgets.QComboBox(self.frame_6)
        self.comboBox_5.setGeometry(QtCore.QRect(55, 5, 101, 27))
        self.comboBox_5.setObjectName("comboBox_5")
        self.label_26 = QtWidgets.QLabel(self.frame_6)
        self.label_26.setGeometry(QtCore.QRect(5, 37, 41, 27))
        self.label_26.setObjectName("label_26")
        self.lineEdit_20 = QtWidgets.QLineEdit(self.frame_6)
        self.lineEdit_20.setGeometry(QtCore.QRect(55, 36, 171, 27))
        self.lineEdit_20.setObjectName("lineEdit_20")
        self.label_27 = QtWidgets.QLabel(self.frame_6)
        self.label_27.setGeometry(QtCore.QRect(3, 65, 51, 27))
        self.label_27.setObjectName("label_27")
        self.lineEdit_21 = QtWidgets.QLineEdit(self.frame_6)
        self.lineEdit_21.setGeometry(QtCore.QRect(55, 65, 171, 27))
        self.lineEdit_21.setObjectName("lineEdit_21")
        self.label_28 = QtWidgets.QLabel(self.frame_6)
        self.label_28.setGeometry(QtCore.QRect(6, 91, 51, 27))
        self.label_28.setObjectName("label_28")
        self.lineEdit_22 = QtWidgets.QLineEdit(self.frame_6)
        self.lineEdit_22.setGeometry(QtCore.QRect(55, 96, 171, 26))
        self.lineEdit_22.setObjectName("lineEdit_22")
        self.checkBox_5 = QtWidgets.QCheckBox(self.frame_6)
        self.checkBox_5.setGeometry(QtCore.QRect(255, 5, 161, 22))
        self.checkBox_5.setObjectName("checkBox_5")
        self.checkBox_6 = QtWidgets.QCheckBox(self.frame_6)
        self.checkBox_6.setGeometry(QtCore.QRect(255, 24, 161, 22))
        self.checkBox_6.setObjectName("checkBox_6")
        self.checkBox_9 = QtWidgets.QCheckBox(self.frame_6)
        self.checkBox_9.setGeometry(QtCore.QRect(254, 43, 161, 22))
        self.checkBox_9.setObjectName("checkBox_9")
        self.checkBox_21 = QtWidgets.QCheckBox(self.frame_6)
        self.checkBox_21.setGeometry(QtCore.QRect(385, 7, 161, 22))
        self.checkBox_21.setObjectName("checkBox_21")
        self.checkBox_7 = QtWidgets.QCheckBox(self.frame_6)
        self.checkBox_7.setGeometry(QtCore.QRect(384, 26, 161, 22))
        self.checkBox_7.setObjectName("checkBox_7")
        self.pushButton = QtWidgets.QPushButton(self.frame_6)
        self.pushButton.setGeometry(QtCore.QRect(332, 95, 161, 27))
        self.pushButton.setObjectName("pushButton")
        self.verticalLayout_7.addWidget(self.frame_6)
        self.plainTextEdit = Q7PythonEditor(self.tPython)
        self.plainTextEdit.setObjectName("plainTextEdit")
        self.verticalLayout_7.addWidget(self.plainTextEdit)
        self.verticalLayout_11.addLayout(self.verticalLayout_7)
        self.tabWidget.addTab(self.tPython, "")
        self.verticalLayout_2.addWidget(self.tabWidget)
        self.verticalLayout_3.addLayout(self.verticalLayout_2)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.bBackControl = QtWidgets.QPushButton(Q7FormWindow)
        self.bBackControl.setMinimumSize(QtCore.QSize(25, 25))
        self.bBackControl.setMaximumSize(QtCore.QSize(25, 25))
        self.bBackControl.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/images/icons/top.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bBackControl.setIcon(icon4)
        self.bBackControl.setObjectName("bBackControl")
        self.horizontalLayout_3.addWidget(self.bBackControl)
        self.bInfo = QtWidgets.QPushButton(Q7FormWindow)
        self.bInfo.setMinimumSize(QtCore.QSize(25, 25))
        self.bInfo.setMaximumSize(QtCore.QSize(25, 25))
        self.bInfo.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/images/icons/help-view.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bInfo.setIcon(icon5)
        self.bInfo.setObjectName("bInfo")
        self.horizontalLayout_3.addWidget(self.bInfo)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.bClose = QtWidgets.QPushButton(Q7FormWindow)
        self.bClose.setObjectName("bClose")
        self.horizontalLayout_3.addWidget(self.bClose)
        self.verticalLayout_3.addLayout(self.horizontalLayout_3)

        self.retranslateUi(Q7FormWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Q7FormWindow)

    def retranslateUi(self, Q7FormWindow):
        _translate = QtCore.QCoreApplication.translate
        Q7FormWindow.setWindowTitle(_translate("Q7FormWindow", "Form"))
        self.label_2.setText(_translate("Q7FormWindow", "Name"))
        self.label_3.setText(_translate("Q7FormWindow", "Label"))
        self.label_6.setText(_translate("Q7FormWindow", "Items"))
        self.label.setText(_translate("Q7FormWindow", "Data"))
        self.label_5.setText(_translate("Q7FormWindow", "min H"))
        self.label_24.setText(_translate("Q7FormWindow", "Size"))
        self.label_7.setText(_translate("Q7FormWindow", "min V"))
        self.bMinimize.setText(_translate("Q7FormWindow", "fit"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tData), _translate("Q7FormWindow", "Table"))
        self.groupBox_3.setTitle(_translate("Q7FormWindow", "Node"))
        self.label_9.setText(_translate("Q7FormWindow", "Path"))
        self.label_10.setText(_translate("Q7FormWindow", "File"))
        self.label_23.setText(_translate("Q7FormWindow", "Size"))
        self.label_8.setText(_translate("Q7FormWindow", "Link level"))
        self.label_13.setText(_translate("Q7FormWindow", "Dir"))
        self.groupBox.setTitle(_translate("Q7FormWindow", "Status"))
        self.checkBox_11.setText(_translate("Q7FormWindow", "Link not found"))
        self.checkBox_8.setText(_translate("Q7FormWindow", "Destination File Read Only"))
        self.checkBox_10.setText(_translate("Q7FormWindow", "Node not found in file"))
        self.checkBox_18.setText(_translate("Q7FormWindow", "File load without following links"))
        self.cChildOfLink.setText(_translate("Q7FormWindow", "Child of a linked node"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tFiles), _translate("Q7FormWindow", "Link"))
        self.cFortranOrderOff.setText(_translate("Q7FormWindow", "Fortran order array is transposed"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tText), _translate("Q7FormWindow", "Text"))
        self.label_11.setText(_translate("Q7FormWindow", "Type"))
        self.label_26.setText(_translate("Q7FormWindow", "Shape"))
        self.label_27.setText(_translate("Q7FormWindow", "Strides"))
        self.label_28.setText(_translate("Q7FormWindow", "Base"))
        self.checkBox_5.setText(_translate("Q7FormWindow", "Data owner"))
        self.checkBox_6.setText(_translate("Q7FormWindow", "Fortran order"))
        self.checkBox_9.setText(_translate("Q7FormWindow", "Contiguous"))
        self.checkBox_21.setText(_translate("Q7FormWindow", "View"))
        self.checkBox_7.setText(_translate("Q7FormWindow", "C order"))
        self.pushButton.setText(_translate("Q7FormWindow", "Run on NODE variable"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tPython), _translate("Q7FormWindow", "Python"))
        self.bClose.setText(_translate("Q7FormWindow", "Close"))
from CGNS.NAV.mtable import Q7TableView
from CGNS.NAV.weditors import Q7PythonEditor
from . import Res_rc



#  -------------------------------------------------------------------------
#  pyCGNS.VAL - Python package for CFD General Notation System - VALidater
#  See license.txt file in the root directory of this Python module source  
#  -------------------------------------------------------------------------
#
import CGNS.PAT.cgnsutils as CGU

def mergeAB(ta, tb, tc, tag, diag, pfxA, pfxB, trace=False):
    paths = CGU.getAllPaths(ta)
    tc[2] = []
    for cta in ta[2]:
        tc[2].append(CGU.nodeCopy(cta))
    for path in paths:
        if path in diag:
            pdg = diag[path]
            for dg in pdg:
                if dg[0] == 'NA':
                    nt = CGU.getNodeByPath(tb, dg[1])
                    nd = CGU.nodeCopy(nt, str(nt[0] + pfxB))
                    np = CGU.getNodeByPath(tc, path)
                    CGU.setChild(np, nd)
                elif dg[0] == 'ND':
                    nt = CGU.getNodeByPath(ta, dg[1])
                    nd = CGU.nodeCopy(nt, str(nt[0] + pfxA))
                    np = CGU.getNodeByPath(tc, path)
                    CGU.setChild(np, nd)
                else:
                    nt = CGU.getNodeByPath(ta, path)
                    nt[0] = str(nt[0] + pfxA)
    return tc



import sys, os

extensions = ["sphinx.ext.autodoc", "sphinx.ext.intersphinx", "sphinx.ext.extlinks"]
mapdir = "%s/../build/doc/html" % os.path.abspath(".")
intersphinx_mapping = {
    "topix": (mapdir + "/", None),
    "mapix": (mapdir + "/MAP", None),
    "patix": (mapdir + "/PAT", None),
    "navix": (mapdir + "/NAV", None),
    "appix": (mapdir + "/APP", None),
    "valix": (mapdir + "/VAL", None),
    "datix": (mapdir + "/DAT", None),
}

# templates_path = ['_templates']
html_theme_path = ["."]
source_suffix = ".txt"

import os

master_doc = os.environ["PYCGNSDOC"]
project = u"pyCGNS"
copyright = u"2001-2016, Marc Poinot"
version = "4"
release = "4.2.0"
unused_docs = ["license.txt"]
exclude_trees = ["build", "doc", "lib", ".hg"]
exclude_dirnames = ["build", "doc", "lib", ".hg"]

pygments_style = "sphinx"
html_theme = "pycgns"
html_title = "%s" % os.environ["PYCGNSMOD"]
html_logo = "images/%s-logo-small.png" % os.environ["PYCGNSMOD"]
html_favicon = "images/pyCGNS-logo-tiny.ico"
html_use_index = True
htmlhelp_basename = "pyCGNSdoc"
html_show_sourcelink = False
html_sidebars = {
    "**": ["localtoc.html", "searchbox.html"],
}

latex_paper_size = "a4"
latex_font_size = "10pt"
latex_documents = [
    (
        os.environ["PYCGNSDOC"],
        "pyCGNS_%s.tex" % os.environ["PYCGNSMOD"],
        u"pyCGNS.%s/Manual" % os.environ["PYCGNSMOD"],
        u"Marc Poinot",
        "manual",
        False,
    ),
]
latex_logo = "images/%s-logo.png" % os.environ["PYCGNSMOD"]
latex_use_parts = False
latex_use_modindex = True

autodoc_member_order = "bysource"

extlinks = {"rsids": ("http://cgns.github.io/CGNS_docs_current/sids/%s", "rsids")}

sids_url = "http://cgns.github.io/CGNS_docs_current/sids"
rst_epilog = ".. |sids_url| replace:: %s" % sids_url

# --- last line



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'CGNS/NAV/T/Q7VTKPlotWindow.ui'
#
# Created: Thu Feb  6 17:40:35 2014
#      by: pyside-uic 0.2.15 running on PySide 1.2.1
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore, QtGui

class Ui_Q7VTKPlotWindow(object):
    def setupUi(self, Q7VTKPlotWindow):
        Q7VTKPlotWindow.setObjectName("Q7VTKPlotWindow")
        Q7VTKPlotWindow.resize(803, 679)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Q7VTKPlotWindow.sizePolicy().hasHeightForWidth())
        Q7VTKPlotWindow.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/cgSpy.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Q7VTKPlotWindow.setWindowIcon(icon)
        self.verticalLayout = QtGui.QVBoxLayout(Q7VTKPlotWindow)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtGui.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.cViews = QtGui.QComboBox(Q7VTKPlotWindow)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cViews.sizePolicy().hasHeightForWidth())
        self.cViews.setSizePolicy(sizePolicy)
        self.cViews.setEditable(True)
        self.cViews.setMaxCount(16)
        self.cViews.setInsertPolicy(QtGui.QComboBox.InsertAtTop)
        self.cViews.setObjectName("cViews")
        self.horizontalLayout.addWidget(self.cViews)
        self.bAddView = QtGui.QPushButton(Q7VTKPlotWindow)
        self.bAddView.setMinimumSize(QtCore.QSize(25, 25))
        self.bAddView.setMaximumSize(QtCore.QSize(25, 25))
        self.bAddView.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/camera-add.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bAddView.setIcon(icon1)
        self.bAddView.setObjectName("bAddView")
        self.horizontalLayout.addWidget(self.bAddView)
        self.bSaveView = QtGui.QPushButton(Q7VTKPlotWindow)
        self.bSaveView.setMinimumSize(QtCore.QSize(25, 25))
        self.bSaveView.setMaximumSize(QtCore.QSize(25, 25))
        self.bSaveView.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/images/icons/camera-snap.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSaveView.setIcon(icon2)
        self.bSaveView.setObjectName("bSaveView")
        self.horizontalLayout.addWidget(self.bSaveView)
        self.bRemoveView = QtGui.QPushButton(Q7VTKPlotWindow)
        self.bRemoveView.setMinimumSize(QtCore.QSize(25, 25))
        self.bRemoveView.setMaximumSize(QtCore.QSize(25, 25))
        self.bRemoveView.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/images/icons/camera-remove.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bRemoveView.setIcon(icon3)
        self.bRemoveView.setObjectName("bRemoveView")
        self.horizontalLayout.addWidget(self.bRemoveView)
        spacerItem = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.bSaveVTK = QtGui.QPushButton(Q7VTKPlotWindow)
        self.bSaveVTK.setMinimumSize(QtCore.QSize(25, 25))
        self.bSaveVTK.setMaximumSize(QtCore.QSize(25, 25))
        self.bSaveVTK.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/images/icons/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSaveVTK.setIcon(icon4)
        self.bSaveVTK.setObjectName("bSaveVTK")
        self.horizontalLayout.addWidget(self.bSaveVTK)
        self.bScreenShot = QtGui.QPushButton(Q7VTKPlotWindow)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bScreenShot.sizePolicy().hasHeightForWidth())
        self.bScreenShot.setSizePolicy(sizePolicy)
        self.bScreenShot.setMinimumSize(QtCore.QSize(25, 25))
        self.bScreenShot.setMaximumSize(QtCore.QSize(25, 25))
        self.bScreenShot.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/images/icons/snapshot.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bScreenShot.setIcon(icon5)
        self.bScreenShot.setObjectName("bScreenShot")
        self.horizontalLayout.addWidget(self.bScreenShot)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.line = QtGui.QFrame(Q7VTKPlotWindow)
        self.line.setFrameShape(QtGui.QFrame.HLine)
        self.line.setFrameShadow(QtGui.QFrame.Sunken)
        self.line.setObjectName("line")
        self.verticalLayout.addWidget(self.line)
        self.horizontalLayout_3 = QtGui.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.bX = QtGui.QPushButton(Q7VTKPlotWindow)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bX.sizePolicy().hasHeightForWidth())
        self.bX.setSizePolicy(sizePolicy)
        self.bX.setMinimumSize(QtCore.QSize(25, 25))
        self.bX.setMaximumSize(QtCore.QSize(25, 25))
        self.bX.setObjectName("bX")
        self.horizontalLayout_3.addWidget(self.bX)
        spacerItem1 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem1)
        self.cVariableX = QtGui.QComboBox(Q7VTKPlotWindow)
        self.cVariableX.setObjectName("cVariableX")
        self.horizontalLayout_3.addWidget(self.cVariableX)
        self.cVariableY = QtGui.QComboBox(Q7VTKPlotWindow)
        self.cVariableY.setObjectName("cVariableY")
        self.horizontalLayout_3.addWidget(self.cVariableY)
        spacerItem2 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.verticalLayout_2 = QtGui.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.display = Q7VTKRenderWindowInteractor(Q7VTKPlotWindow)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.display.sizePolicy().hasHeightForWidth())
        self.display.setSizePolicy(sizePolicy)
        self.display.setObjectName("display")
        self.verticalLayout_2.addWidget(self.display)
        self.verticalLayout.addLayout(self.verticalLayout_2)
        self.horizontalLayout_2 = QtGui.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.bBackControl = QtGui.QPushButton(Q7VTKPlotWindow)
        self.bBackControl.setMinimumSize(QtCore.QSize(25, 25))
        self.bBackControl.setMaximumSize(QtCore.QSize(25, 25))
        self.bBackControl.setText("")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/images/icons/top.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bBackControl.setIcon(icon6)
        self.bBackControl.setObjectName("bBackControl")
        self.horizontalLayout_2.addWidget(self.bBackControl)
        spacerItem3 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem3)
        self.sIndex1 = QtGui.QSpinBox(Q7VTKPlotWindow)
        self.sIndex1.setObjectName("sIndex1")
        self.horizontalLayout_2.addWidget(self.sIndex1)
        self.sIndex2 = QtGui.QSpinBox(Q7VTKPlotWindow)
        self.sIndex2.setObjectName("sIndex2")
        self.horizontalLayout_2.addWidget(self.sIndex2)
        spacerItem4 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem4)
        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.retranslateUi(Q7VTKPlotWindow)
        QtCore.QMetaObject.connectSlotsByName(Q7VTKPlotWindow)

    def retranslateUi(self, Q7VTKPlotWindow):
        Q7VTKPlotWindow.setWindowTitle(QtGui.QApplication.translate("Q7VTKPlotWindow", "Form", None, QtGui.QApplication.UnicodeUTF8))
        self.bAddView.setToolTip(QtGui.QApplication.translate("Q7VTKPlotWindow", "Add current view to view list", None, QtGui.QApplication.UnicodeUTF8))
        self.bSaveView.setToolTip(QtGui.QApplication.translate("Q7VTKPlotWindow", "Write view list into a file", None, QtGui.QApplication.UnicodeUTF8))
        self.bRemoveView.setToolTip(QtGui.QApplication.translate("Q7VTKPlotWindow", "Remove current view from view list", None, QtGui.QApplication.UnicodeUTF8))
        self.bSaveVTK.setToolTip(QtGui.QApplication.translate("Q7VTKPlotWindow", "Save VTK data into a file", None, QtGui.QApplication.UnicodeUTF8))
        self.bScreenShot.setToolTip(QtGui.QApplication.translate("Q7VTKPlotWindow", "Save view snapshot into a file", None, QtGui.QApplication.UnicodeUTF8))
        self.bX.setToolTip(QtGui.QApplication.translate("Q7VTKPlotWindow", "Show Y/Z plane", None, QtGui.QApplication.UnicodeUTF8))
        self.bX.setText(QtGui.QApplication.translate("Q7VTKPlotWindow", "X/Y", None, QtGui.QApplication.UnicodeUTF8))
        self.bBackControl.setToolTip(QtGui.QApplication.translate("Q7VTKPlotWindow", "Raise CGNS.NAV control window", None, QtGui.QApplication.UnicodeUTF8))

from CGNS.NAV.Q7VTKRenderWindowInteractor import Q7VTKRenderWindowInteractor
import Res_rc



#  -------------------------------------------------------------------------
#  pyCGNS - Python package for CFD General Notation System
#  See license.txt file in the root directory of this Python module source
#  -------------------------------------------------------------------------
# Change these values to fit your installation
#
# --- If you leave empty the variables below the build process would
#     try to guess for you, using your current environment variables.
#     Change these values only if you need to add/change something.
#
# --- stuff to add for numpy (used by NAV)
#     you should not change this, the numpy stuff is expected to be detected
#     using the numpy import itself
#

if False:
    NUMPY_VERSION = ""
    NUMPY_PATH_INCLUDES = []
    NUMPY_PATH_LIBRARIES = [""]
    NUMPY_LINK_LIBRARIES = [""]
    NUMPY_EXTRA_ARGS = []
#
# --- stuff to add for HDF5 (used by MAP)
#     the hdf5 install is detected using a 'which h5dump' and then we parse the
#     installation. Thus non-standard installs would require to set these vars
#
if True:
    HDF5_VERSION = ""
    HDF5_PATH_INCLUDES = [
        "",
    ]
    HDF5_PATH_LIBRARIES = [
        "",
    ]
    HDF5_LINK_LIBRARIES = ["hdf5"]
    HDF5_EXTRA_ARGS = ["-Wno-return-type"]

# -------------------------------------------------------------------------



#  -------------------------------------------------------------------------
#  pyCGNS - Python package for CFD General Notation System -
#  See license.txt file in the root directory of this Python module source  
#  -------------------------------------------------------------------------
#
# --------------------------------------------------------------------
MAJOR_VERSION = 6
MINOR_VERSION = 0
REVISION = 0
# --------------------------------------------------------------------

import os
import platform
import sys
import shutil
import re
import time
import pathlib
import distutils.util

from distutils.dir_util import remove_tree
from distutils.command.clean import clean as _clean

rootfiles = ['__init__.py', 'errors.py', 'version.py', 'config.py', 'test.py']
compfiles = []

pfx = '#'
def line(msg=""):
    print("{} {}".format(pfx, "-" * 70))
    if msg:
        print("{} --- {}".format(pfx, msg))

def log(msg):
    print("{} {}".format(pfx, msg))

# if you change this name, also change lines tagged with 'USER CONFIG'
userconfigfile = 'setup_userConfig.py'

class ConfigException(Exception):
    pass

def is_windows():
    if sys.platform == 'win32':
        return 1
    else:
        return 0

def is_python3():
    if sys.version_info[0] < 3:
        return 0
    else:
        return 1


# Please leave integers here, these will be used in the SIDS-to-Python C code
HAS_MSW = is_windows()

def fix_path(path):
    """All paths should be POSIX paths. Translation is required only for windows."""
    return pathlib.Path(path).as_posix()
        
# --------------------------------------------------------------------
def prodtag():
    from time import gmtime, strftime
    proddate = strftime("%Y-%m-%d %H:%M:%S", gmtime())
    try:
        prodhost = platform.uname()
    except AttributeError:
        prodhost = ('???', '???', '???')
    return (proddate, prodhost)

# http://stackoverflow.com/questions/377017/test-if-executable-exists-in-python
def which(program):
    import os
    def is_exe(fpath):
        return os.path.isfile(fpath) and os.access(fpath, os.X_OK)

    fpath, fname = os.path.split(program)
    if fpath:
        if is_exe(program):
            return program
    else:
        for path in os.environ["PATH"].split(os.pathsep):
            path = path.strip('"')
            exe_file = os.path.join(path, program)
            if is_exe(exe_file):
                return exe_file
            w_exe_file = exe_file + '.exe'
            if is_exe(w_exe_file):
                return w_exe_file
            b_exe_file = exe_file + '.bat'
            if is_exe(b_exe_file):
                return b_exe_file

    return None

# --------------------------------------------------------------------
def unique_but_keep_order(lst):
    if len(lst) < 2:
        return lst
    r = [lst[0]]
    for p in lst[1:]:
        if p not in r:
            r.append(p)
    return r

# --------------------------------------------------------------------
def search(incs, libs, tag='pyCGNS',
           deps=['Cython', 'HDF5', 'numpy', 'vtk', 'qtpy']):
    state = 1
    for com in sys.argv:
        if com in ['help', 'clean']: state = 0
    pt = distutils.util.get_platform()
    vv = "%d.%d" % (sys.version_info[0], sys.version_info[1])
    tg = "%s/./build/lib.%s-%s/CGNS" % (os.getcwd(), pt, vv)
    bptarget = tg
    if (not os.path.exists(bptarget)): os.makedirs(bptarget)
    oldsyspath = sys.path
    sys.path = [os.path.abspath(os.path.normpath('./lib'))]
    cfgdict = {}
    import pyCGNSconfig_default as C_D
    sys.path = oldsyspath
    for ck in dir(C_D):
        if ck[0] != '_':
            cfgdict[ck] = C_D.__dict__[ck]
    pg = prodtag()
    cfgdict['PFX'] = pfx
    cfgdict['DATE'] = pg[0]
    cfgdict['PLATFORM'] = "%s %s %s" % (pg[1][0], pg[1][1], pg[1][-1])
    cfgdict['HAS_MSW'] = HAS_MSW
    updateConfig('..', bptarget, cfgdict)
    sys.path = [bptarget] + sys.path

    # here we go, check each dep and add incs/libs/others to config
    try:
        import pyCGNSconfig as C

        # -----------------------------------------------------------------------
        C.COM_UIC = 'true'
        C.COM_RCC = 'true'
        C.COM_CYTHON = 'true'        
        if ('Cython' in deps):
            try:
                if (which('cython') is not None):
                    C.COM_CYTHON = 'cython'
                elif (which('cython3') is not None):
                    C.COM_CYTHON = 'cython3'
                else:
                    raise Exception
                if (which('pyuic') is not None):  C.COM_UIC = 'pyuic'
                if (which('pyrcc') is not None):  C.COM_RCC = 'pyrcc'
                if (which('pyuic5') is not None): C.COM_UIC = 'pyuic5'
                if (which('pyrcc5') is not None): C.COM_RCC = 'pyrcc5'
                import Cython
                C.HAS_CYTHON = True
                log('found Cython v%s' % Cython.__version__)
                log('using Cython from {}'.format(os.path.dirname(Cython.__file__)))
                C.HAS_CYTHON_2PLUS = False
                C.CYTHON_VERSION = Cython.__version__
                try:
                    if (float(Cython.__version__[:3]) > 0.1):
                        C.HAS_CYTHON_2PLUS = True
                    else:
                        log('***** SKIP Cython version cannot build CGNS')
                except:
                    log('***** SKIP Cython version cannot build CGNS')
            except:
                C.HAS_CYTHON = False
                log('***** FATAL: Cython not found')

        # -----------------------------------------------------------------------
        if ('qtpy' in deps):
            try:
                import qtpy
                import qtpy.QtCore
                import qtpy.QtGui
                import qtpy.QtWidgets

                C.HAS_QTPY = True
                log('found qtpy v{}'.format(qtpy.__version__))
                log('using qtpy from {}'.format(os.path.dirname(qtpy.__file__)))
                log('using qtpy with Qt v{}'.format(qtpy.QtCore.__version__))
                C.PYQT_VERSION = str(qtpy.__version__)
                C.QT_VERSION = str(qtpy.QtCore.__version__)
            except:
                C.HAS_QTPY = False
                log('***** SKIP NAV: qtpy not found')

        # -----------------------------------------------------------------------
        if ('vtk' in deps):
            try:
                import vtk
                v = vtk.vtkVersion()
                C.HAS_VTK = True
                log('found vtk (python module) v%s' % v.GetVTKVersion())
                C.VTK_VERSION = v.GetVTKVersion()
            except:
                C.HAS_VTK = False
                log('***** SKIP NAV/VTK: no vtk python module')

        # -----------------------------------------------------------------------
        if ('h5py' in deps):
            log('using h5py alternate implementation for CGNS.MAP')
            try:
                import warnings
                warnings.simplefilter(action='ignore', category=FutureWarning)
                import h5py
                v = h5py.version.version
                C.HDF5_VERSION = h5py.version.hdf5_version
                log('found h5py (python module) v{}'.format(h5py.version.version))
                log('using HDF5 v{}'.format(C.HDF5_VERSION))
                C.HAS_H5PY = 1
            except:
                log('***** FATAL: setup cannot find h5py and its HDF5')
                sys.exit(1)

        # -----------------------------------------------------------------------
        if ('numpy' in deps):
            incs = incs + C.NUMPY_PATH_INCLUDES
            libs = libs + C.NUMPY_PATH_LIBRARIES
            tp = find_numpy(incs, libs, C.NUMPY_LINK_LIBRARIES)
            if (tp is None):
                log('***** FATAL: setup cannot find Numpy')
                sys.exit(1)
            (C.NUMPY_VERSION,
             C.NUMPY_VERSION_API,
             C.NUMPY_PATH_INCLUDES,
             C.NUMPY_PATH_LIBRARIES,
             C.NUMPY_LINK_LIBRARIES,
             C.NUMPY_EXTRA_ARGS) = tp
            log('found Numpy version %s' % (C.NUMPY_VERSION,))
            log('using Numpy API version %s' % (C.NUMPY_VERSION_API,))
            log('using Numpy headers from %s' % (C.NUMPY_PATH_INCLUDES[0]))
            C.HAS_NUMPY = True
            incs = incs + C.NUMPY_PATH_INCLUDES
            libs = libs + C.NUMPY_PATH_LIBRARIES

        # -----------------------------------------------------------------------
        if ('HDF5' in deps):
            log('using HDF5 raw C API implementation for CGNS.MAP')
            try:
                import pkgconfig
            except ImportError:
                log('Failed to import pkgconfig')
                class pkgconfig(object):
                    @classmethod
                    def exists(cls, name):
                        return False
            try:
               if pkgconfig.exists('hdf5'):
                   log('Using pkgconfig for HDF5 detection')
                   pkgcfg = pkgconfig.parse("hdf5")
                   incs = incs + pkgcfg['include_dirs']
                   libs = libs + pkgcfg['library_dirs']
            except EnvironmentError:
                pass
            hdf5_ci = os.environ.get('HDF5_DIR')
            if hdf5_ci is not None:
               log('Using HDF5_DIR environment variable')
               incs = incs + [os.path.join(hdf5_ci, 'include'),]
               libs = libs + [os.path.join(hdf5_ci, 'lib'),]
            incs = incs + C.HDF5_PATH_INCLUDES + C.INCLUDE_DIRS
            libs = libs + C.HDF5_PATH_LIBRARIES + C.LIBRARY_DIRS
            tp = find_HDF5(incs, libs, C.HDF5_LINK_LIBRARIES)
            if (tp is None):
                log('***** FATAL: setup cannot find HDF5')
                sys.exit(1)
            (C.HDF5_VERSION,
             C.HDF5_PATH_INCLUDES,
             C.HDF5_PATH_LIBRARIES,
             C.HDF5_LINK_LIBRARIES,
             C.HDF5_EXTRA_ARGS,
             C.HDF5_HST,
             C.HDF5_H64,
             C.HDF5_HUP,
             C.HDF5_PARALLEL) = tp
            log('found HDF5 %s' % (C.HDF5_VERSION,))
            log('using HDF5 headers from %s' % (C.HDF5_PATH_INCLUDES[0]))
            log('using HDF5 libs from %s' % (C.HDF5_PATH_LIBRARIES[0]))
            if C.HDF5_PARALLEL:
                log('using HDF5 parallel version (cython uses $MPICC)')
            C.HAS_HDF5 = True
            C.HAS_H5PY = 0
            incs = incs + C.HDF5_PATH_INCLUDES + C.INCLUDE_DIRS
            libs = libs + C.HDF5_PATH_LIBRARIES + C.LIBRARY_DIRS

            # ---------------------------------------------------------------------

    except ImportError:
        log('***** FATAL: setup cannot find pyCGNSconfig.py file!')
        sys.exit(1)
    C.HDF5_PATH_INCLUDES = list(set(C.HDF5_PATH_INCLUDES))
    C.HDF5_PATH_LIBRARIES = list(set(C.HDF5_PATH_LIBRARIES))
    C.NUMPY_PATH_INCLUDES = list(set(C.NUMPY_PATH_INCLUDES))
    C.NUMPY_PATH_LIBRARIES = list(set(C.NUMPY_PATH_LIBRARIES))

    incs = unique_but_keep_order(incs)
    libs = unique_but_keep_order(libs)

    C.INCLUDE_DIRS = incs
    C.LIBRARY_DIRS = libs

    C.PRODUCTION_DIR = bptarget

    updateConfig('..', bptarget, C.__dict__, cfgdict)

    return (C, state)


# --------------------------------------------------------------------
def installConfigFiles(bptarget):
    lptarget = '.'
    for ff in rootfiles:
        shutil.copy("%s/lib/%s" % (lptarget, ff), "%s/%s" % (bptarget, ff))
    for ff in compfiles:
        shutil.copy("%s/lib/compatibility/%s" % (lptarget, ff), "%s/%s" % (bptarget, ff))


# --------------------------------------------------------------------
def updateVersionInFile(filename, cfg):
    f = open('{}/revision.tmp'.format(cfg.PRODUCTION_DIR))
    r = int(f.readlines()[0][:-1])
    REVISION = r
    f = open(filename, 'r')
    l = f.readlines()
    f.close()
    vver = '@@UPDATEVERSION@@'
    vrel = '@@UPDATERELEASE@@'
    vrev = '@@UPDATEREVISION@@'
    r = []
    for ll in l:
        rl = ll
        if (ll[-len(vver) - 1:-1] == vver):
            rl = '__version__=%s # %s\n' % (MAJOR_VERSION, vver)
        if (ll[-len(vrel) - 1:-1] == vrel):
            rl = '__release__=%s # %s\n' % (MINOR_VERSION, vrel)
        if (ll[-len(vrev) - 1:-1] == vrev):
            ACTUALREV = REVISION
            rl = '__revision__=%s # %s\n' % (ACTUALREV, vrev)
        r += [rl]
    f = open(filename, 'w+')
    f.writelines(r)
    f.close()
    cfg.REVISION = REVISION

# --------------------------------------------------------------------
# Clean target redefinition - force clean everything
relist = [r'^.*~$', r'^core\.*$', r'^pyCGNS\.log\..*$',
          r'^#.*#$', r'^.*\.aux$', r'^.*\.pyc$', r'^.*\.bak$', r'^.*\.l2h',
          r'^Output.*$']
reclean = []

for restring in relist:
    reclean.append(re.compile(restring))


def wselect(args, dirname, names):
    for n in names:
        for rev in reclean:
            if (rev.match(n)):
                # print "%s/%s"%(dirname,n)
                os.remove("%s/%s" % (dirname, n))
                break


class clean(_clean):
    def run(self):
        import glob
        rdirs = glob.glob("./build/*")
        for d in rdirs: remove_tree(d)
        if os.path.exists("./build"):     remove_tree("./build")
        if os.path.exists("./Doc/_HTML"): remove_tree("./Doc/_HTML")
        if os.path.exists("./Doc/_PS"):   remove_tree("./Doc/_PS")
        if os.path.exists("./Doc/_PDF"):  remove_tree("./Doc/_PDF")


# --------------------------------------------------------------------
def confValueAsStr(v):
    if (type(v) == type((1,))): return str(v)
    if (type(v) == type([])):   return str(v)
    if (v in [True, False]):
        return str(v)
    else:
        return '"%s"' % str(v)


# --------------------------------------------------------------------
def updateConfig(pfile, gfile, config_default, config_previous=None):
    if (config_previous):
        from pyCGNSconfig_default import file_pattern as fpat
        cfg = config_default
        for ck in config_previous:
            if ck not in cfg:
                cfg[ck] = config_previous[ck]
        log("+++++ update pyCGNSconfig.py file")
        os.unlink("%s/pyCGNSconfig.py" % (gfile))
        f = open("%s/pyCGNSconfig.py" % (gfile), 'w+')
        f.writelines(fpat % cfg)
        f.close()
        return
    elif (not os.path.exists("%s/pyCGNSconfig.py" % (gfile))):
        log("+++++ create new pyCGNSconfig.py file")
        newconf = 1
    else:
        f1 = os.stat("%s/pyCGNSconfig.py" % (gfile))
        if (os.path.exists("%s/%s" % (pfile, userconfigfile))):
            f2 = os.stat("%s/%s" % (pfile, userconfigfile))
        else:
            f2 = os.stat("./%s" % userconfigfile)
        if (f1.st_mtime < f2.st_mtime):
            newconf = 1
            log("using modified %s file" % userconfigfile)
        else:
            newconf = 0
            log("using existing %s file" % userconfigfile)
    if newconf:
        sys.path = ['..'] + ['.'] + sys.path
        import setup_userConfig as UCFG  # USER CONFIG
        for ck in dir(UCFG):
            if (ck[0] != '_'): config_default[ck] = UCFG.__dict__[ck]
        if (not os.path.exists('%s' % gfile)):
            os.makedirs('%s' % gfile)
        f = open("%s/pyCGNSconfig.py" % (gfile), 'w+')
        f.writelines(config_default['file_pattern'] % config_default)
        f.close()


# --------------------------------------------------------------------
def frompath_HDF5():
    h5p = which("h5dump")
    if h5p is not None:
        h5root = '/'.join(h5p.split('/')[:-2])
    else:
        h5root = '/usr/local'
    return h5root

def guess_path_python():
    return os.path.dirname(sys.executable)

# --------------------------------------------------------------------
def find_HDF5(pincs, plibs, libs):
    notfound = 1
    extraargs = []
    vers = ''
    h5root = frompath_HDF5()
    pincs += [h5root, '%s/include' % h5root]
    if sys.platform == 'win32':
        pth = guess_path_python()
        pincs += [h5root, '{}\\Library\\include'.format(pth)]
    plibs += [h5root, '%s/lib64' % h5root]
    plibs += [h5root, '%s/lib' % h5root]
    if sys.platform == 'win32':
        pth = guess_path_python()
        plibs += [h5root, '{}\\Library\\lib'.format(pth)]
    pincs = unique_but_keep_order(pincs)
    plibs = unique_but_keep_order(plibs)
    for pth in plibs:
        if ((os.path.exists(pth + '/libhdf5.a'))
            or (os.path.exists(pth + '/libhdf5.so'))
            or (os.path.exists(pth + '/libhdf5.lib'))
            or (os.path.exists(pth + '/libhdf5.sl'))):
            notfound = 0
            plibs = [pth]
            break
    if notfound:
        log("***** FATAL: libhdf5 not found, please check paths:")
        for ppl in plibs:
            print(pfx, ppl)
    notfound = 1
    for pth in pincs:
        if (os.path.exists(pth + '/hdf5.h')): notfound = 0
    if notfound:
        log("***** FATAL: hdf5.h not found, please check paths")
        for ppi in pincs:
            print(pfx, ppi)
        return None

    ifh = 'HDF5 library version: unknown'
    notfound = 1
    for pth in pincs:
        if (os.path.exists(pth + '/H5public.h')):
            fh = open(pth + '/H5public.h', 'r')
            fl = fh.readlines()
            fh.close()
            found = 0
            for ifh in fl:
                if (ifh[:21] == "#define H5_VERS_INFO "):
                    vers = ifh.split('"')[1].split()[-1]
                    found = 1
            if found:
                pincs = [pth]
                notfound = 0
                break
    if notfound:
        log("***** FATAL: cannot find hdf5 version, please check paths")
        for ppi in pincs:
            print(pfx, pincs)
        return None

    h64 = 0
    hup = 1
    hst = 1
    if (os.path.exists(pth + '/H5pubconf.h')):
        hup = 1
        hst = 1
        hfn = pth + '/H5pubconf.h'
    if (os.path.exists(pth + '/h5pubconf.h')):
        hup = 0
        hst = 1
        hfn = pth + '/h5pubconf.h'
    if (os.path.exists(pth + '/H5pubconf-64.h')):
        h64 = 1
        hup = 1
        hfn = pth + '/H5pubconf-64.h'
    if (os.path.exists(pth + '/h5pubconf-64.h')):
        h64 = 1
        hup = 0
        hfn = pth + '/h5pubconf-64.h'
    has_parallel = False
    if (os.path.exists(hfn)):
        fh = open(hfn, 'r')
        fl = fh.readlines()
        fh.close()
        found = 0
        for ifh in fl:
            if (ifh[:26] == "#define H5_HAVE_PARALLEL 1"):
                has_parallel = True
    return (vers, pincs, plibs, libs, extraargs, hst, h64, hup, has_parallel)

# --------------------------------------------------------------------
def find_numpy(pincs, plibs, libs):
    try:
        import numpy
    except ImportError:
        log("**** FATAL cannot import numpy")
        sys.exit(0)
    apivers = ''
    vers = numpy.version.version
    extraargs = []
    pdir = os.path.normpath(sys.prefix)
    xdir = os.path.normpath(sys.exec_prefix)
    if sys.platform == 'win32':
        pth = guess_path_python()
        pincs += ['{}\\Library\\include'.format(pth)]
    pincs += ['%s/lib/python%s/site-packages/numpy/core/include' \
              % (xdir, sys.version[:3])]
    pincs += ['%s/lib/python%s/site-packages/numpy/core/include' \
              % (pdir, sys.version[:3])]
    pincs += [numpy.get_include()]
    notfound = 1
    pincs = unique_but_keep_order(pincs)
    plibs = unique_but_keep_order(plibs)
    for pth in pincs:
        if (os.path.exists(pth + '/numpy/ndarrayobject.h')):
            fh = open(pth + '/numpy/ndarrayobject.h', 'r')
            fl = fh.readlines()
            fh.close()
            found = 0
            for ifh in fl:
                if (ifh[:20] == "#define NPY_VERSION "):
                    apivers = ifh.split()[-1]
                    found = 1
            if found:
                pincs = [pth]
                notfound = 0
                break
        if (os.path.exists(pth + '/numpy/_numpyconfig.h')):
            fh = open(pth + '/numpy/_numpyconfig.h', 'r')
            fl = fh.readlines()
            fh.close()
            found = 0
            for ifh in fl:
                if (ifh[:24] == "#define NPY_ABI_VERSION "):
                    apivers = ifh.split()[-1]
                    found = 1
            if found:
                pincs = [pth]
                notfound = 0
                break
    if notfound:
        log("***** FATAL: numpy headers not found, please check your paths")
        log(pincs)
        return None

    return (vers, apivers, pincs, plibs, libs, extraargs)


# --------------------------------------------------------------------
def touch(filename):
    now = time.time()
    os.utime(filename, (now, now))

# --- last line



#  -------------------------------------------------------------------------
#  pyCGNS.VAL - Python package for CFD General Notation System - VALidater
#  See license.txt file in the root directory of this Python module source  
#  -------------------------------------------------------------------------
#
import CGNS.VAL.parse.messages as CGM

messagetable=(
('S0101',CGM.CHECK_FAIL,'Unknown ZoneType value'),
('S0102',CGM.CHECK_FAIL,'Unknown SimulationType value'),
('S0103',CGM.CHECK_FAIL,'Unknown GridLocation value'),
('S0104',CGM.CHECK_FAIL,'Unknown GridConnectivityType value'),
('S0105',CGM.CHECK_FAIL,'Unknown DataClass value'),
('S0106',CGM.CHECK_FAIL,'Unknown BCDataType value'),
('S0107',CGM.CHECK_FAIL,'Unknown RigidMotionType value'),
('S0108',CGM.CHECK_FAIL,'Unknown BCType value'),
('S0109',CGM.CHECK_FAIL,'Unknown ElementType value'),
('S0110',CGM.CHECK_FAIL,'Unknown MassUnit value'),
('S0111',CGM.CHECK_FAIL,'Unknown LengthUnit value'),
('S0112',CGM.CHECK_FAIL,'Unknown TimeUnit value'),
('S0113',CGM.CHECK_FAIL,'Unknown TemperatureUnit value'),
('S0114',CGM.CHECK_FAIL,'Unknown AngleUnit value'),
('S0115',CGM.CHECK_FAIL,'Unknown ElectricCurrentUnit value'),
('S0116',CGM.CHECK_FAIL,'Unknown SubstanceAmountUnit value'),
('S0117',CGM.CHECK_FAIL,'Unknown LuminousIntensityUnit value'),
('S0118',CGM.CHECK_FAIL,'Unknown ArbitraryMotionType value'),
('S0119',CGM.CHECK_FAIL,'Unknown PointSetType value'),
('S0120',CGM.CHECK_FAIL,'Name [%s] is reserved for a child of type [%s]'),
('S0121',CGM.CHECK_WARN,'Name [%s] is not known as a CGNS/SIDS identifier'),
('S0122',CGM.CHECK_FAIL,'Name [%s] is not authorized for a node of type [%s], should be in list [%s]'),
('S0123',CGM.CHECK_WARN,'Default [%s] is set to [%s]'),

('S0150',CGM.CHECK_WARN,'No default DataClass set'),
('S0151',CGM.CHECK_WARN,'Default GridLocation is set to Vertex'),
('S0152',CGM.CHECK_WARN,'Default GridConnectivityType is set to Overset'),
('S0153',CGM.CHECK_WARN,'DataClass defined without DimensionalUnits'),
('S0154',CGM.CHECK_WARN,'Local DataClass refers to a parent DimensionalUnits'),
('S0155',CGM.CHECK_WARN,'DataArray refers to a parent DataClass'),
('S0156',CGM.CHECK_FAIL,'DimensionalExponents without DataClass'),
('S0157',CGM.CHECK_FAIL,'DimensionalExponents without DimensionalUnits'),
('S0158',CGM.CHECK_WARN,'DataConversion without DataClass'),
('S0159',CGM.CHECK_WARN,'DataConversion without DimensionalUnits'),
('S0160',CGM.CHECK_WARN,'DataConversion without DimensionalExponents'),
('S0161',CGM.CHECK_FAIL,'DataClass requires DimensionalUnits'),
('S0162',CGM.CHECK_WARN,'DataClass does not require DimensionalUnits'),
('S0163',CGM.CHECK_WARN,'DataClass does not require DimensionalExponents'),
('S0164',CGM.CHECK_FAIL,'DimensionalUnits without DataClass'),

('S0170',CGM.CHECK_FAIL,'Unknown AverageInterfaceType value'),
('S0171',CGM.CHECK_FAIL,'Unknown GeometryFormat value'),
('S0172',CGM.CHECK_FAIL,'Unknown GoverningEquationsType value'),
('S0173',CGM.CHECK_FAIL,'Unknown ThermalConductivityModelType value'),
('S0174',CGM.CHECK_FAIL,'Unknown TurbulenceClosureType value'),
('S0175',CGM.CHECK_FAIL,'Unknown ThermalConductivityModelIdentifier value'),
('S0176',CGM.CHECK_FAIL,'Unknown TurbulenceClosureIdentifier value'),
('S0177',CGM.CHECK_FAIL,'Unknown TurbulenceModelType value'),
('S0178',CGM.CHECK_FAIL,'Unknown ViscosityModelType value'),
('S0179',CGM.CHECK_FAIL,'Unknown ViscosityModelIdentifier value'),
('S0180',CGM.CHECK_FAIL,'Unknown GasModelType value'),
('S0181',CGM.CHECK_FAIL,'Unknown GasModelIdentifier value'),
('S0182',CGM.CHECK_FAIL,'Unknown ThermalRelaxationModelType value'),
('S0183',CGM.CHECK_FAIL,'Unknown ChemicalKineticsModelType value'),
('S0184',CGM.CHECK_FAIL,'Unknown ChemicalKineticsModelIdentifier value'),
('S0185',CGM.CHECK_FAIL,'Unknown EMElectricFieldModelType value'),
('S0186',CGM.CHECK_FAIL,'Unknown EMMagneticFieldModelType value'),
('S0187',CGM.CHECK_FAIL,'Unknown EMConductivityModelType value'),
('S0188',CGM.CHECK_FAIL,'Unknown EMConductivityModelIdentifier value'),
('S0189',CGM.CHECK_FAIL,'Unknown BCTypeSimple value'),
('S0190',CGM.CHECK_FAIL,'Unknown BCTypeCompound value'),
('S0191',CGM.CHECK_FAIL,'Bad node value shape'),
('S0192',CGM.CHECK_FAIL,'Unexpected shape [%s] instead of [%s] for [%s]'),
('S0193',CGM.CHECK_FAIL,'Missing required node of type [%s] in [%s]'),
('S0194',CGM.CHECK_FAIL,'Missing required node of name [%s]'),
('S0195',CGM.CHECK_FAIL,'Bad child node value shape [%s]'),
('S0196',CGM.CHECK_FAIL,'Bad child node value datatype [%s]'),
('S0197',CGM.CHECK_FAIL,'Inconsistent child node value [%s]'),
('S0198',CGM.CHECK_FAIL,'Missing child [%s] in case child [%s] present'),
('S0199',CGM.CHECK_FAIL,'DataType [%s] not allowed for this node, expected type among [%s]'),

('S0201',CGM.CHECK_FAIL,'Inconsistent PhysicalDimension/CellDimension'),
('S0202',CGM.CHECK_FAIL,'Bad value for CellDimension'),
('S0203',CGM.CHECK_FAIL,'Bad value for PhysicalDimension'),
('S0204',CGM.CHECK_FAIL,'Bad Transform values'),
('S0205',CGM.CHECK_FAIL,'Bad ElementSizeBoundary value'),

('S0206',CGM.CHECK_FAIL,'Values out of range'),
('S0207',CGM.CHECK_WARN,'Values not ordered'),
('S0208',CGM.CHECK_WARN,'Values appear several times in list'),

('S0209',CGM.CHECK_FAIL,'Bad combination of ElementRange values'),
('S0210',CGM.CHECK_WARN,'[%s] suitable for face Elements only'),
('S0211',CGM.CHECK_FAIL,'Values out of range for GridLocation [%s], index [%s/%s], accepted range within [%s]'),
('S0212',CGM.CHECK_FAIL,'Unvalid element at position [%s] for [%s] face type'),
('S0213',CGM.CHECK_FAIL,'Bad [%s] face position [%s] for parent element [%s]'),
('S0214',CGM.CHECK_FAIL,'ParentElements child required together with ParentElementsPosition'),
('S0215',CGM.CHECK_FAIL,'GridLocation [%s] not valid for CellDimension [%s] and RegionCellDimension [%s]'),
('S0216',CGM.CHECK_FAIL,'GridLocation [%s] not valid'),
('S0217',CGM.CHECK_FAIL,'Values out of range, index [%s/%s], accepted range within [%s]'),
('S0218',CGM.CHECK_FAIL,'GridLocation [%s] not valid for [%s] node, required among [%s]'),
('S0219',CGM.CHECK_FAIL,'A face is expected'),
('S0220',CGM.CHECK_FAIL,'Prohibited (0,0) adjacent cell couples for face elements [%s]'),

('S0221',CGM.CHECK_WARN,'BCType is [%s]'),
('S0222',CGM.CHECK_FAIL,'Both PointRange and PointList children is not allowed'),
('S0223',CGM.CHECK_FAIL,'PointRange or PointList child is mandatory'),
('S0224',CGM.CHECK_FAIL,'One and only one of these children is mandatory: %s'),

('S0230',CGM.CHECK_FAIL,'Bad [%s] values, expected [%s]'),

('S0260',CGM.CHECK_FAIL,'GridCoordinates node has no coordinate array'),
('S0261',CGM.CHECK_FAIL,'Coordinates number different from PhysicalDimension'),
('S0262',CGM.CHECK_FAIL,'Size of coordinates different from zone DataSize (VertexSize if no Rind)'),
('S0263',CGM.CHECK_FAIL,'Unable to identify coordinate system from names'),
('S0264',CGM.CHECK_FAIL,'Coordinate name not allowed for 1D system'),
('S0265',CGM.CHECK_FAIL,'Coordinate name not allowed for 2D system'),
('S0266',CGM.CHECK_FAIL,'Coordinate name not allowed for 3D system'),

('S0270',CGM.CHECK_WARN,'Descriptor contains non-printable or non-ascii chars'),
('S0271',CGM.CHECK_WARN,'Descriptor is empty (no data)'),

('S0280',CGM.CHECK_FAIL,'DiffusionModel should have a value'),
('S0281',CGM.CHECK_FAIL,'DiffusionModel value should have dimension of %d'),
('S0282',CGM.CHECK_FAIL,'DiffusionModel value should contain only 0s or 1s'),

('S0300',CGM.CHECK_FAIL,'FamilyName is empty'),
('S0301',CGM.CHECK_FAIL,'Reference to unknown family [%s]'),
('S0302',CGM.CHECK_FAIL,'Reference to unknown additional family [%s]'),
('S0303',CGM.CHECK_WARN,'Family is never referenced'),
('S0304',CGM.CHECK_FAIL,'FamilyName_t child is mandatory for FamilySpecified BC'),
('S0305',CGM.CHECK_WARN,'FamilyBC_t node should have FamilyBC name'),

('S0400',CGM.CHECK_FAIL,'Cannot get connectivity donor zone'),
('S0401',CGM.CHECK_FAIL,'Connectivity donor zone [%s] not found'),

('S0501',CGM.CHECK_FAIL,'Reference to unknown node [%s] in [%s]'),
('S0502',CGM.CHECK_FAIL,'Bad iteration number [%s]'),
('S0503',CGM.CHECK_FAIL,'Name [%s] is reserved for time-dependant pointers'),
('S0504',CGM.CHECK_FAIL,'Name [%s] is reserved for ConvergenceHistory'),

('S0600',CGM.CHECK_WARN,'CGNSTree has no CGNSBase'),
('S0601',CGM.CHECK_WARN,'CGNSBase has no Zone'),
('S0602',CGM.CHECK_FAIL,'Zone has no GridCoordinates'),
('S0603',CGM.CHECK_FAIL,'No GridCoordinates_t of name GridCoordinates in zone'),
('S0604',CGM.CHECK_WARN,'ZoneBC has no BC'),
('S0605',CGM.CHECK_FAIL,'Unstructured zone has no Elements'),
('S0606',CGM.CHECK_FAIL,'ElementConnectivity child node absent'),
('S0607',CGM.CHECK_FAIL,'ElementRange child node absent'),
('S0608',CGM.CHECK_FAIL,'Structured zone should not have Elements'),
('S0609',CGM.CHECK_WARN,'ElementRange is reserved for Elements of unstructured zones'),
('S0610',CGM.CHECK_FAIL,'ElementStartOffset child node absent'),

('S0620',CGM.CHECK_FAIL,'GridConnectivity1to1 only applies to structured zones interfacing with structured donors'),
('S0621',CGM.CHECK_FAIL,'Opposite GridConnectivity1to1 not found in zone [%s]'),

('S0700',CGM.CHECK_WARN,'Faces [%s] defined as boundary regarding [%s] do not belong to any BC or GridConnectivity'),
('S0701',CGM.CHECK_WARN,'Faces [%s] defined as boundary regarding [%s] belong to more than one BC and/or GridConnectivity'),
('S0702',CGM.CHECK_WARN,'Boundary [%s] face indices [%s] do not belong to any BC or GridConnectivity'),
('S0703',CGM.CHECK_WARN,'Boundary [%s] face indices [%s] belong to more than one BC and/or GridConnectivity'),
('S0704',CGM.CHECK_FAIL,'Elements [%s] declared as boundary faces regarding ElementSizeBoundary should have one adjacent cell declared 0 in ParentElements'),

('S0710',CGM.CHECK_WARN,'Node inconsistent with [%s] zone type'),

)




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'CGNS/NAV/T/Q7MessageWindow.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Q7MessageWindow(object):
    def setupUi(self, Q7MessageWindow):
        Q7MessageWindow.setObjectName("Q7MessageWindow")
        Q7MessageWindow.resize(500, 200)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Q7MessageWindow.sizePolicy().hasHeightForWidth())
        Q7MessageWindow.setSizePolicy(sizePolicy)
        Q7MessageWindow.setMinimumSize(QtCore.QSize(500, 200))
        Q7MessageWindow.setMaximumSize(QtCore.QSize(1200, 600))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/cgSpy.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Q7MessageWindow.setWindowIcon(icon)
        self.verticalLayout = QtWidgets.QVBoxLayout(Q7MessageWindow)
        self.verticalLayout.setObjectName("verticalLayout")
        self.eMessage = QtWidgets.QTextEdit(Q7MessageWindow)
        self.eMessage.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("DejaVu Sans Mono")
        self.eMessage.setFont(font)
        self.eMessage.setFrameShadow(QtWidgets.QFrame.Plain)
        self.eMessage.setLineWidth(0)
        self.eMessage.setUndoRedoEnabled(False)
        self.eMessage.setTextInteractionFlags(QtCore.Qt.NoTextInteraction)
        self.eMessage.setObjectName("eMessage")
        self.verticalLayout.addWidget(self.eMessage)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.bInfo = QtWidgets.QPushButton(Q7MessageWindow)
        self.bInfo.setMinimumSize(QtCore.QSize(25, 25))
        self.bInfo.setMaximumSize(QtCore.QSize(25, 25))
        self.bInfo.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/help-view.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bInfo.setIcon(icon1)
        self.bInfo.setObjectName("bInfo")
        self.horizontalLayout_2.addWidget(self.bInfo)
        self.cNotAgain = QtWidgets.QCheckBox(Q7MessageWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cNotAgain.sizePolicy().hasHeightForWidth())
        self.cNotAgain.setSizePolicy(sizePolicy)
        self.cNotAgain.setObjectName("cNotAgain")
        self.horizontalLayout_2.addWidget(self.cNotAgain)
        spacerItem = QtWidgets.QSpacerItem(868, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.bCANCEL = QtWidgets.QPushButton(Q7MessageWindow)
        self.bCANCEL.setObjectName("bCANCEL")
        self.horizontalLayout_2.addWidget(self.bCANCEL)
        self.bOK = QtWidgets.QPushButton(Q7MessageWindow)
        self.bOK.setObjectName("bOK")
        self.horizontalLayout_2.addWidget(self.bOK)
        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.retranslateUi(Q7MessageWindow)
        QtCore.QMetaObject.connectSlotsByName(Q7MessageWindow)

    def retranslateUi(self, Q7MessageWindow):
        _translate = QtCore.QCoreApplication.translate
        Q7MessageWindow.setWindowTitle(_translate("Q7MessageWindow", "Dialog"))
        self.cNotAgain.setText(_translate("Q7MessageWindow", "Don\'t show this message again"))
        self.bCANCEL.setText(_translate("Q7MessageWindow", "Cancel"))
        self.bOK.setText(_translate("Q7MessageWindow", "OK"))
from . import Res_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'CGNS/NAV/T/Q7VTKWindow.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Q7VTKWindow(object):
    def setupUi(self, Q7VTKWindow):
        Q7VTKWindow.setObjectName("Q7VTKWindow")
        Q7VTKWindow.resize(700, 402)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Q7VTKWindow.sizePolicy().hasHeightForWidth())
        Q7VTKWindow.setSizePolicy(sizePolicy)
        Q7VTKWindow.setMinimumSize(QtCore.QSize(700, 400))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/cgSpy.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Q7VTKWindow.setWindowIcon(icon)
        self.verticalLayout = QtWidgets.QVBoxLayout(Q7VTKWindow)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.cViews = QtWidgets.QComboBox(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cViews.sizePolicy().hasHeightForWidth())
        self.cViews.setSizePolicy(sizePolicy)
        self.cViews.setEditable(True)
        self.cViews.setMaxCount(16)
        self.cViews.setInsertPolicy(QtWidgets.QComboBox.InsertAtTop)
        self.cViews.setObjectName("cViews")
        self.horizontalLayout.addWidget(self.cViews)
        self.bAddView = QtWidgets.QPushButton(Q7VTKWindow)
        self.bAddView.setMinimumSize(QtCore.QSize(25, 25))
        self.bAddView.setMaximumSize(QtCore.QSize(25, 25))
        self.bAddView.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/camera-add.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bAddView.setIcon(icon1)
        self.bAddView.setObjectName("bAddView")
        self.horizontalLayout.addWidget(self.bAddView)
        self.bSaveView = QtWidgets.QPushButton(Q7VTKWindow)
        self.bSaveView.setMinimumSize(QtCore.QSize(25, 25))
        self.bSaveView.setMaximumSize(QtCore.QSize(25, 25))
        self.bSaveView.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/images/icons/camera-snap.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSaveView.setIcon(icon2)
        self.bSaveView.setObjectName("bSaveView")
        self.horizontalLayout.addWidget(self.bSaveView)
        self.bRemoveView = QtWidgets.QPushButton(Q7VTKWindow)
        self.bRemoveView.setMinimumSize(QtCore.QSize(25, 25))
        self.bRemoveView.setMaximumSize(QtCore.QSize(25, 25))
        self.bRemoveView.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/images/icons/camera-remove.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bRemoveView.setIcon(icon3)
        self.bRemoveView.setObjectName("bRemoveView")
        self.horizontalLayout.addWidget(self.bRemoveView)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.bColorMapMin = QtWidgets.QPushButton(Q7VTKWindow)
        self.bColorMapMin.setMinimumSize(QtCore.QSize(25, 25))
        self.bColorMapMin.setMaximumSize(QtCore.QSize(25, 25))
        self.bColorMapMin.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/images/icons/colors-first.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bColorMapMin.setIcon(icon4)
        self.bColorMapMin.setObjectName("bColorMapMin")
        self.horizontalLayout.addWidget(self.bColorMapMin)
        self.bColorMapMax = QtWidgets.QPushButton(Q7VTKWindow)
        self.bColorMapMax.setMinimumSize(QtCore.QSize(25, 25))
        self.bColorMapMax.setMaximumSize(QtCore.QSize(25, 25))
        self.bColorMapMax.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/images/icons/colors-last.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bColorMapMax.setIcon(icon5)
        self.bColorMapMax.setObjectName("bColorMapMax")
        self.horizontalLayout.addWidget(self.bColorMapMax)
        self.cVariables = QtWidgets.QComboBox(Q7VTKWindow)
        self.cVariables.setObjectName("cVariables")
        self.horizontalLayout.addWidget(self.cVariables)
        self.cColorSpace = QtWidgets.QComboBox(Q7VTKWindow)
        self.cColorSpace.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.cColorSpace.setObjectName("cColorSpace")
        self.horizontalLayout.addWidget(self.cColorSpace)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.bSaveVTK = QtWidgets.QPushButton(Q7VTKWindow)
        self.bSaveVTK.setMinimumSize(QtCore.QSize(25, 25))
        self.bSaveVTK.setMaximumSize(QtCore.QSize(25, 25))
        self.bSaveVTK.setText("")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/images/icons/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSaveVTK.setIcon(icon6)
        self.bSaveVTK.setObjectName("bSaveVTK")
        self.horizontalLayout.addWidget(self.bSaveVTK)
        self.bScreenShot = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bScreenShot.sizePolicy().hasHeightForWidth())
        self.bScreenShot.setSizePolicy(sizePolicy)
        self.bScreenShot.setMinimumSize(QtCore.QSize(25, 25))
        self.bScreenShot.setMaximumSize(QtCore.QSize(25, 25))
        self.bScreenShot.setText("")
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/images/icons/snapshot.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bScreenShot.setIcon(icon7)
        self.bScreenShot.setObjectName("bScreenShot")
        self.horizontalLayout.addWidget(self.bScreenShot)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.line = QtWidgets.QFrame(Q7VTKWindow)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.verticalLayout.addWidget(self.line)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.bX = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bX.sizePolicy().hasHeightForWidth())
        self.bX.setSizePolicy(sizePolicy)
        self.bX.setMinimumSize(QtCore.QSize(25, 25))
        self.bX.setMaximumSize(QtCore.QSize(25, 25))
        self.bX.setObjectName("bX")
        self.horizontalLayout_3.addWidget(self.bX)
        self.bY = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bY.sizePolicy().hasHeightForWidth())
        self.bY.setSizePolicy(sizePolicy)
        self.bY.setMinimumSize(QtCore.QSize(25, 25))
        self.bY.setMaximumSize(QtCore.QSize(25, 25))
        self.bY.setObjectName("bY")
        self.horizontalLayout_3.addWidget(self.bY)
        self.bZ = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bZ.sizePolicy().hasHeightForWidth())
        self.bZ.setSizePolicy(sizePolicy)
        self.bZ.setMinimumSize(QtCore.QSize(25, 25))
        self.bZ.setMaximumSize(QtCore.QSize(25, 25))
        self.bZ.setObjectName("bZ")
        self.horizontalLayout_3.addWidget(self.bZ)
        self.cMirror = QtWidgets.QCheckBox(Q7VTKWindow)
        self.cMirror.setObjectName("cMirror")
        self.horizontalLayout_3.addWidget(self.cMirror)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.bZoom = QtWidgets.QPushButton(Q7VTKWindow)
        self.bZoom.setMinimumSize(QtCore.QSize(25, 25))
        self.bZoom.setMaximumSize(QtCore.QSize(25, 25))
        self.bZoom.setText("")
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/images/icons/zoompoint.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bZoom.setIcon(icon8)
        self.bZoom.setCheckable(True)
        self.bZoom.setObjectName("bZoom")
        self.horizontalLayout_3.addWidget(self.bZoom)
        self.selectable = QtWidgets.QPushButton(Q7VTKWindow)
        self.selectable.setMinimumSize(QtCore.QSize(25, 25))
        self.selectable.setMaximumSize(QtCore.QSize(25, 25))
        self.selectable.setCursor(QtGui.QCursor(QtCore.Qt.OpenHandCursor))
        self.selectable.setText("")
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/images/icons/lock-legend.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.selectable.setIcon(icon9)
        self.selectable.setCheckable(True)
        self.selectable.setObjectName("selectable")
        self.horizontalLayout_3.addWidget(self.selectable)
        self.cShowValue = QtWidgets.QPushButton(Q7VTKWindow)
        self.cShowValue.setMinimumSize(QtCore.QSize(25, 25))
        self.cShowValue.setMaximumSize(QtCore.QSize(25, 25))
        self.cShowValue.setText("")
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/images/icons/value.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cShowValue.setIcon(icon10)
        self.cShowValue.setCheckable(True)
        self.cShowValue.setObjectName("cShowValue")
        self.horizontalLayout_3.addWidget(self.cShowValue)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem3)
        self.bSuffleColors = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bSuffleColors.sizePolicy().hasHeightForWidth())
        self.bSuffleColors.setSizePolicy(sizePolicy)
        self.bSuffleColors.setMinimumSize(QtCore.QSize(25, 25))
        self.bSuffleColors.setMaximumSize(QtCore.QSize(25, 25))
        self.bSuffleColors.setText("")
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/images/icons/colors.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSuffleColors.setIcon(icon11)
        self.bSuffleColors.setObjectName("bSuffleColors")
        self.horizontalLayout_3.addWidget(self.bSuffleColors)
        self.bBlackColor = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bBlackColor.sizePolicy().hasHeightForWidth())
        self.bBlackColor.setSizePolicy(sizePolicy)
        self.bBlackColor.setMinimumSize(QtCore.QSize(25, 25))
        self.bBlackColor.setMaximumSize(QtCore.QSize(25, 25))
        self.bBlackColor.setText("")
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/images/icons/colors-bw.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bBlackColor.setIcon(icon12)
        self.bBlackColor.setObjectName("bBlackColor")
        self.horizontalLayout_3.addWidget(self.bBlackColor)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem4)
        self.bAnimateWindow = QtWidgets.QPushButton(Q7VTKWindow)
        self.bAnimateWindow.setMinimumSize(QtCore.QSize(25, 25))
        self.bAnimateWindow.setMaximumSize(QtCore.QSize(25, 25))
        self.bAnimateWindow.setText("")
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/images/icons/anim-view.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bAnimateWindow.setIcon(icon13)
        self.bAnimateWindow.setObjectName("bAnimateWindow")
        self.horizontalLayout_3.addWidget(self.bAnimateWindow)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem5)
        self.bResetCamera = QtWidgets.QPushButton(Q7VTKWindow)
        self.bResetCamera.setMinimumSize(QtCore.QSize(25, 25))
        self.bResetCamera.setMaximumSize(QtCore.QSize(25, 25))
        self.bResetCamera.setText("")
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/images/icons/zoom-actor.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bResetCamera.setIcon(icon14)
        self.bResetCamera.setObjectName("bResetCamera")
        self.horizontalLayout_3.addWidget(self.bResetCamera)
        self.cRotationAxis = QtWidgets.QComboBox(Q7VTKWindow)
        self.cRotationAxis.setObjectName("cRotationAxis")
        self.horizontalLayout_3.addWidget(self.cRotationAxis)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.display = Q7VTKRenderWindowInteractor(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.display.sizePolicy().hasHeightForWidth())
        self.display.setSizePolicy(sizePolicy)
        self.display.setObjectName("display")
        self.verticalLayout_2.addWidget(self.display)
        self.verticalLayout.addLayout(self.verticalLayout_2)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.bUpdateFromTree = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(25)
        sizePolicy.setVerticalStretch(25)
        sizePolicy.setHeightForWidth(self.bUpdateFromTree.sizePolicy().hasHeightForWidth())
        self.bUpdateFromTree.setSizePolicy(sizePolicy)
        self.bUpdateFromTree.setMinimumSize(QtCore.QSize(25, 25))
        self.bUpdateFromTree.setMaximumSize(QtCore.QSize(25, 25))
        self.bUpdateFromTree.setText("")
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/images/icons/user-U.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bUpdateFromTree.setIcon(icon15)
        self.bUpdateFromTree.setObjectName("bUpdateFromTree")
        self.horizontalLayout_4.addWidget(self.bUpdateFromTree)
        self.cCurrentPath = Q7ComboBox(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cCurrentPath.sizePolicy().hasHeightForWidth())
        self.cCurrentPath.setSizePolicy(sizePolicy)
        self.cCurrentPath.setEditable(False)
        self.cCurrentPath.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToMinimumContentsLength)
        self.cCurrentPath.setMinimumContentsLength(100)
        self.cCurrentPath.setObjectName("cCurrentPath")
        self.horizontalLayout_4.addWidget(self.cCurrentPath)
        self.bUpdateFromVTK = QtWidgets.QPushButton(Q7VTKWindow)
        self.bUpdateFromVTK.setMinimumSize(QtCore.QSize(25, 25))
        self.bUpdateFromVTK.setMaximumSize(QtCore.QSize(25, 25))
        self.bUpdateFromVTK.setText("")
        self.bUpdateFromVTK.setIcon(icon15)
        self.bUpdateFromVTK.setObjectName("bUpdateFromVTK")
        self.horizontalLayout_4.addWidget(self.bUpdateFromVTK)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.line_2 = QtWidgets.QFrame(Q7VTKWindow)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.verticalLayout.addWidget(self.line_2)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.bBackControl = QtWidgets.QPushButton(Q7VTKWindow)
        self.bBackControl.setMinimumSize(QtCore.QSize(25, 25))
        self.bBackControl.setMaximumSize(QtCore.QSize(25, 25))
        self.bBackControl.setText("")
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/images/icons/top.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bBackControl.setIcon(icon16)
        self.bBackControl.setObjectName("bBackControl")
        self.horizontalLayout_2.addWidget(self.bBackControl)
        self.bInfo = QtWidgets.QPushButton(Q7VTKWindow)
        self.bInfo.setMinimumSize(QtCore.QSize(25, 25))
        self.bInfo.setMaximumSize(QtCore.QSize(25, 25))
        self.bInfo.setText("")
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/images/icons/help-view.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bInfo.setIcon(icon17)
        self.bInfo.setObjectName("bInfo")
        self.horizontalLayout_2.addWidget(self.bInfo)
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem6)
        self.sIndex1 = QtWidgets.QSpinBox(Q7VTKWindow)
        self.sIndex1.setObjectName("sIndex1")
        self.horizontalLayout_2.addWidget(self.sIndex1)
        self.sIndex2 = QtWidgets.QSpinBox(Q7VTKWindow)
        self.sIndex2.setObjectName("sIndex2")
        self.horizontalLayout_2.addWidget(self.sIndex2)
        self.sIndex3 = QtWidgets.QSpinBox(Q7VTKWindow)
        self.sIndex3.setObjectName("sIndex3")
        self.horizontalLayout_2.addWidget(self.sIndex3)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem7)
        self.cShowFamily = QtWidgets.QCheckBox(Q7VTKWindow)
        self.cShowFamily.setChecked(True)
        self.cShowFamily.setObjectName("cShowFamily")
        self.horizontalLayout_2.addWidget(self.cShowFamily)
        self.cShowZone = QtWidgets.QCheckBox(Q7VTKWindow)
        self.cShowZone.setChecked(True)
        self.cShowZone.setObjectName("cShowZone")
        self.horizontalLayout_2.addWidget(self.cShowZone)
        self.cShowBC = QtWidgets.QCheckBox(Q7VTKWindow)
        self.cShowBC.setChecked(False)
        self.cShowBC.setObjectName("cShowBC")
        self.horizontalLayout_2.addWidget(self.cShowBC)
        self.cShowCT = QtWidgets.QCheckBox(Q7VTKWindow)
        self.cShowCT.setChecked(False)
        self.cShowCT.setObjectName("cShowCT")
        self.horizontalLayout_2.addWidget(self.cShowCT)
        self.bPrevious = QtWidgets.QPushButton(Q7VTKWindow)
        self.bPrevious.setMinimumSize(QtCore.QSize(25, 25))
        self.bPrevious.setMaximumSize(QtCore.QSize(25, 25))
        self.bPrevious.setText("")
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(":/images/icons/control.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bPrevious.setIcon(icon18)
        self.bPrevious.setObjectName("bPrevious")
        self.horizontalLayout_2.addWidget(self.bPrevious)
        self.bReset = QtWidgets.QPushButton(Q7VTKWindow)
        self.bReset.setMinimumSize(QtCore.QSize(25, 25))
        self.bReset.setMaximumSize(QtCore.QSize(25, 25))
        self.bReset.setText("")
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(":/images/icons/node-sids-leaf.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bReset.setIcon(icon19)
        self.bReset.setObjectName("bReset")
        self.horizontalLayout_2.addWidget(self.bReset)
        self.bNext = QtWidgets.QPushButton(Q7VTKWindow)
        self.bNext.setMinimumSize(QtCore.QSize(25, 25))
        self.bNext.setMaximumSize(QtCore.QSize(25, 25))
        self.bNext.setText("")
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(":/images/icons/node-sids-closed.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bNext.setIcon(icon20)
        self.bNext.setObjectName("bNext")
        self.horizontalLayout_2.addWidget(self.bNext)
        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.retranslateUi(Q7VTKWindow)
        QtCore.QMetaObject.connectSlotsByName(Q7VTKWindow)

    def retranslateUi(self, Q7VTKWindow):
        _translate = QtCore.QCoreApplication.translate
        Q7VTKWindow.setWindowTitle(_translate("Q7VTKWindow", "Form"))
        Q7VTKWindow.setToolTip(_translate("Q7VTKWindow", "Show value"))
        self.bAddView.setToolTip(_translate("Q7VTKWindow", "Add current view to view list"))
        self.bSaveView.setToolTip(_translate("Q7VTKWindow", "Write view list into a file"))
        self.bRemoveView.setToolTip(_translate("Q7VTKWindow", "Remove current view from view list"))
        self.bColorMapMin.setToolTip(_translate("Q7VTKWindow", "Set color for palette high bound"))
        self.bColorMapMax.setToolTip(_translate("Q7VTKWindow", "Set color for palette low bound"))
        self.bSaveVTK.setToolTip(_translate("Q7VTKWindow", "Save VTK data into a file"))
        self.bScreenShot.setToolTip(_translate("Q7VTKWindow", "Save view snapshot into a file"))
        self.bX.setToolTip(_translate("Q7VTKWindow", "Show Y/Z plane"))
        self.bX.setText(_translate("Q7VTKWindow", "X"))
        self.bY.setToolTip(_translate("Q7VTKWindow", "Show X/Z plane"))
        self.bY.setText(_translate("Q7VTKWindow", "Y"))
        self.bZ.setToolTip(_translate("Q7VTKWindow", "Show X/Y plane"))
        self.bZ.setText(_translate("Q7VTKWindow", "Z"))
        self.cMirror.setText(_translate("Q7VTKWindow", "Mirror"))
        self.bZoom.setToolTip(_translate("Q7VTKWindow", "Activate Mouse Zoom mode"))
        self.selectable.setToolTip(_translate("Q7VTKWindow", "Acticate Move Legend Mode"))
        self.cShowValue.setToolTip(_translate("Q7VTKWindow", "Activate Show Value Mode"))
        self.bSuffleColors.setToolTip(_translate("Q7VTKWindow", "Change colors to random"))
        self.bBlackColor.setToolTip(_translate("Q7VTKWindow", "Switch black/white colors"))
        self.bResetCamera.setToolTip(_translate("Q7VTKWindow", "Zoom and center on selected"))
        self.cRotationAxis.setToolTip(_translate("Q7VTKWindow", "Rotation axis"))
        self.bUpdateFromTree.setToolTip(_translate("Q7VTKWindow", "Reset VTK view selection from tree view FIRST selected node"))
        self.bUpdateFromVTK.setToolTip(_translate("Q7VTKWindow", "Reset tree view selection from ALL VTK view selected objects"))
        self.bBackControl.setToolTip(_translate("Q7VTKWindow", "Raise CGNS.NAV control window"))
        self.sIndex3.setToolTip(_translate("Q7VTKWindow", "Get/Set index for third dim"))
        self.cShowFamily.setText(_translate("Q7VTKWindow", "Families"))
        self.cShowZone.setText(_translate("Q7VTKWindow", "Zones"))
        self.cShowBC.setText(_translate("Q7VTKWindow", "BCs"))
        self.cShowCT.setText(_translate("Q7VTKWindow", "CTs"))
        self.bPrevious.setToolTip(_translate("Q7VTKWindow", "Highlight previous selected item"))
        self.bReset.setToolTip(_translate("Q7VTKWindow", "Clear selection list"))
        self.bNext.setToolTip(_translate("Q7VTKWindow", "Highlight next selected item"))
from CGNS.NAV.Q7VTKRenderWindowInteractor import Q7VTKRenderWindowInteractor
from CGNS.NAV.wvtkutils import Q7ComboBox
from . import Res_rc



#!/usr/bin/env python
import CGNS.MAP
import CGNS.PAT.cgnsutils as PU
import numpy
import time
import sys

numpy.set_printoptions(threshold=sys.maxint)

flags = CGNS.MAP.S2P_FOLLOWLINKS | CGNS.MAP.S2P_TRACE
start = time.clock()
(tree, links) = CGNS.MAP.load("./001Disk.hdf", flags)

node = PU.getNodeByPath(tree, "/Disk/zone1/ZoneBC/ext1/PointRange")

print("PointRange is fortran:", numpy.isfortran(node[1]), node[1], node[1].shape)

f = open("T0.py", "w+")
f.write("from numpy import *\n")
f.write("tree=")
f.write(str(tree))
f.write("\nlinks=")
f.write(str(links))
f.write("\n")
f.close()

CGNS.MAP.save("./002Disk.hdf", tree, links, flags)

end = time.clock()
print("# time =", end - start)
